#!/usr/bin/env python
"""
vault secret store rest api client.

Vault is used to protect secrets in a secure way
using a golang restful web api.  This client is
a wrapper to enable authentication and restful
interactions with the vault rest endpoint.
https://github.com/hashicorp/vault
"""

import os
import sys

__author__ = "Gary Wright<zerosignal0@msn.com>"
__contributors__ = ["Gary Wright"]
__version__ = "1.0.0"
__maintainer__ = "Gary Wright"
__team_email__ = "zerosignal0@msn.com"
__script_name__ = os.path.basename(sys.argv[0])

class VaultError(Exception):
    def __init__(self, message=None, errors=None):
        if errors:
            message = ', '.join(errors)

        self.errors = errors

        super(VaultError, self).__init__(message)

class InvalidRequest(VaultError):
    pass

class Unauthorized(VaultError):
    pass

class InvalidPath(VaultError):
    pass

class RateLimitExceeded(VaultError):
    pass

class InternalServerError(VaultError):
    pass

class VaultDown(VaultError):
    pass

class UnexpectedError(VaultError):
    pass
